@@ -96,7 +96,7 @@ xmlNodePtr Tdom_parser::xpath_get_node(std::string expr, xmlXPathContextPtr xpat
 	}
 	else {
 		xmlNodeSetPtr nodes = xpathObj->nodesetval;
-		xmlNodePtr result;	
+		xmlNodePtr result = NULL;	
 		if (nodes != NULL and nodes->nodeNr != 0)
 			result = nodes->nodeTab[0];
 		xmlXPathFreeObject(xpathObj);
